pub struct NodeService<S, B, Input>{ /* private fields */ }Expand description
A service that wraps another service to handle encoding and decoding of task inputs and outputs using the backend’s codec.
Implementations
Sourceimpl<S, B, Input> NodeService<S, B, Input>
impl<S, B, Input> NodeService<S, B, Input>