Module node

Module node 

Graph node implementations

Structs

GraphNodeService
A service that wraps another service to handle encoding and decoding of task inputs and outputs using the backend’s codec.