pub struct GraphNodeService<S, B, Input>{ /* private fields */ }Expand description
A service that wraps another service to handle encoding and decoding of task inputs and outputs using the backend’s codec.
Implementations